@@ -937,6 +937,8 @@ class Generator:
                             result.append(braille.Region(
                                 object_properties.TABLE_CELL_DELIMITER_BRAILLE))
                         result.extend(cellResult)
+
+                result.extend(self._generatePositionInList(obj, **args))
             else:
                 result.extend(self._generateRealTableCell(obj, **args))
         else:
@@ -1001,21 +1003,6 @@ class Generator:
 
         return [displayedText]
 
-    def _generateListItemMarker(self, obj, **args):
-        startOffset = args.get('startOffset', 0)
-        if not (0 <= startOffset <= 1):
-            return []
-
-        endOffset = args.get('endOffset')
-        if endOffset is not None and endOffset == startOffset:
-            return []
-
-        listItemMarker = self._script.utilities.getListItemMarkerText(obj)
-        if listItemMarker:
-            return [listItemMarker]
-
-        return []
-
     #####################################################################
     #                                                                   #
     # Tree interface information                                        #
@@ -1166,6 +1153,9 @@ class Generator:
     def _generatePageSummary(self, obj, **args):
         return []
 
+    def _generatePositionInList(self, obj, **args):
+        return []
+
     def _generateProgressBarIndex(self, obj, **args):
         return []
 
