@@ -111,7 +111,10 @@ class BrailleGenerator(braille_generator.BrailleGenerator):
             return []
 
         if self._script.utilities.inDocumentContent(obj) and obj.name:
-            return [obj.name]
+            name = obj.name
+            if not self._script.utilities.hasExplicitName(obj):
+                name = name.strip()
+            return [name]
 
         return super()._generateLabelOrName(obj, **args)
 
@@ -142,10 +145,14 @@ class BrailleGenerator(braille_generator.BrailleGenerator):
         if self._script.utilities.preferDescriptionOverName(obj):
             return [obj.description]
 
-        if not self._script.utilities.hasValidName(obj):
+        if obj.name and not self._script.utilities.hasValidName(obj):
             return []
 
-        return super()._generateName(obj, **args)
+        result = super()._generateName(obj, **args)
+        if result and result[0] and not self._script.utilities.hasExplicitName(obj):
+            result[0] = result[0].strip()
+
+        return result
 
     def _generateExpandedEOCs(self, obj, **args):
         """Returns the expanded embedded object characters for an object."""
@@ -191,6 +198,8 @@ class BrailleGenerator(braille_generator.BrailleGenerator):
             oldRole = self._overrideRole(pyatspi.ROLE_STATIC, args)
         elif self._script.utilities.treatAsDiv(obj, offset=args.get('startOffset')):
             oldRole = self._overrideRole(pyatspi.ROLE_SECTION, args)
+        elif self._script.utilities.treatAsEntry(obj):
+            oldRole = self._overrideRole(pyatspi.ROLE_ENTRY, args)
 
         if obj.getRole() == pyatspi.ROLE_MENU_ITEM:
             comboBox = self._script.utilities.ancestorWithRole(
